@@ -25,6 +25,11 @@ __all__ = [
     'vector',
     'vector3',
     'vector4',
+    'Matrix33',
+    'Matrix44',
+    'Quaternion',
+    'Vector3',
+    'Vector4',
 ]
 
 from . import (
@@ -48,3 +53,20 @@ from . import (
     vector3,
     vector4,
 )
+
+from .objects import (
+    Matrix33,
+    Matrix44,
+    Quaternion,
+    Vector3,
+    Vector4
+)
+
+# because of circular imports, we cannot put these inside each module
+# so insert them here
+setattr(matrix33, 'Matrix33', Matrix33)
+setattr(matrix44, 'Matrix44', Matrix44)
+setattr(quaternion, 'Quaternion', Quaternion)
+setattr(vector3, 'Vector3', Vector3)
+setattr(vector4, 'Vector4', Vector4)
+
